@@ -2,6 +2,7 @@ import random
 import sys
 import binascii
 import base58
+import base64
 import requests
 from coincurve.keys import PrivateKey
 from coincurve._libsecp256k1 import ffi
@@ -22,7 +23,7 @@ class CenterIdentity:
             'public_key': public_key
         }
 
-        self.url_prefix = url_prefix or 'http://localhost:8000'
+        self.url_prefix = url_prefix or 'https://centeridentity.com'
 
     def from_wif(self):
         return binascii.hexlify(base58.b58decode(self.wif))[2:-10].decode()
